R/get-gtfs-feeds.R
filter_feedlist.RdFilter a feedlist to include only valid urls (ending in .zip and connect)
filter_feedlist(feedlist_df, test_url = FALSE)
| feedlist_df | A dataframe of feed metadata such as output from get_feedlist |
|---|---|
| test_url | Boolean. Whether to test if the url connects or not. FALSE by default (can take a while). |
A dataframe of feed metadata for all feeds in input that are downloadable